@@ -4,7 +4,7 @@
 ;; Base16: (https://github.com/tinted-theming/home)
 
 ;;; Authors:
-;; Scheme: Geoffrey Teale (tealeg@gmail.com)
+;; Scheme: Geoffrey Teale (tealeg@gmail.com), Tinted Theming (https://github.com/tinted-theming)
 ;; Template: Kaleb Elwert <belak@coded.io>
 
 ;;; Code:
@@ -13,21 +13,21 @@
 
 (defvar base16-heetch-light-theme-colors
   '(:base00 "#feffff"
-    :base01 "#392551"
-    :base02 "#7b6d8b"
+    :base01 "#dedae2"
+    :base02 "#bdb6c5"
     :base03 "#9c92a8"
-    :base04 "#ddd6e5"
+    :base04 "#7b6d8b"
     :base05 "#5a496e"
-    :base06 "#470546"
+    :base06 "#392551"
     :base07 "#190134"
-    :base08 "#27d9d5"
-    :base09 "#bdb6c5"
-    :base0A "#5ba2b6"
-    :base0B "#f80059"
-    :base0C "#c33678"
-    :base0D "#47f9f5"
-    :base0E "#bd0152"
-    :base0F "#dedae2")
+    :base08 "#f80059"
+    :base09 "#bd0152"
+    :base0A "#bd9701"
+    :base0B "#5bb66a"
+    :base0C "#47f9f5"
+    :base0D "#5ba2b6"
+    :base0E "#8f6c97"
+    :base0F "#58425d")
   "All colors for Base16 Heetch Light are defined here.")
 
 ;; Define the theme
